/// <reference types="react" />
import * as React from "react";
import * as PropTypes from "prop-types";
import StyleManager from "../styles/StyleManager";
import getTheme from "../styles/getTheme";
import ToastWrapper from "../Toast/ToastWrapper";
export { getTheme };
export interface DataProps {
    theme?: ReactUWP.ThemeType;
    autoSaveTheme?: boolean;
    themeWillUpdate?: (theme?: ReactUWP.ThemeType) => void;
    onGeneratedAcrylic?: (theme?: ReactUWP.ThemeType) => void;
    needGenerateAcrylic?: boolean;
}
export interface ThemeProps extends DataProps, React.HTMLAttributes<HTMLDivElement> {
}
export interface ThemeState {
    currTheme?: ReactUWP.ThemeType;
}
export declare class Theme extends React.Component<ThemeProps, ThemeState> {
    static defaultProps: ThemeProps;
    static childContextTypes: {
        theme: PropTypes.Requireable<any>;
    };
    acrylicTextureCount: number;
    themeClassName: string;
    cacheDarkAcrylicTextures: ReactUWP.ThemeType;
    cacheLightAcrylicTextures: ReactUWP.ThemeType;
    toastWrapper: ToastWrapper;
    prevStyleManager: StyleManager;
    getDefaultTheme: () => ReactUWP.ThemeType;
    getLocalStorageTheme: () => ReactUWP.ThemeType;
    generateAcrylicTextures: (currTheme: ReactUWP.ThemeType, themeCallback?: (theme?: ReactUWP.ThemeType) => void) => void;
    bindNewThemeMethods: (theme: ReactUWP.ThemeType) => void;
    handleNewTheme: (theme: ReactUWP.ThemeType) => void;
    state: ThemeState;
    getChildContext(): {
        theme: ReactUWP.ThemeType;
    };
    componentDidMount(): void;
    componentWillReceiveProps(nextProps: ThemeProps): void;
    componentWillUpdate(nextProps: ThemeProps, nextState: ThemeState): void;
    componentDidUpdate(): void;
    componentWillUnmount(): void;
    updateTheme: (newTheme?: ReactUWP.ThemeType, callback?: (theme?: ReactUWP.ThemeType) => void) => void;
    forceUpdateTheme: (currTheme: ReactUWP.ThemeType) => void;
    saveTheme: (newTheme?: ReactUWP.ThemeType, callback?: (theme?: ReactUWP.ThemeType) => void) => void;
    sureNeedGenerateAcrylic: (newTheme: ReactUWP.ThemeType) => boolean;
    addToast: (toast: React.ReactNode) => void;
    updateToast: (toastID: number, toast: React.ReactNode) => void;
    deleteToast: (toastID: number) => void;
    handleScrollReveal: (e?: Event) => void;
    cleanLocalStorage: () => void;
    render(): JSX.Element;
}
export default Theme;
